@@ -10,7 +10,6 @@ import asyncio
 import sys
 import threading
 import traceback
-from asyncio.locks import Event
 from time import monotonic
 from typing import (
     Any,
@@ -26,6 +25,7 @@ from typing import (
 
 from .services import Service
 from .utils.futures import maybe_async, maybe_set_exception, maybe_set_result, notify
+from .utils.locks import Event
 
 __all__ = [
     "QueuedMethod",
@@ -104,16 +104,18 @@ class ServiceThread(Service):
         **kwargs: Any,
     ) -> None:
         # cannot share loop between threads, so create a new one
+        assert asyncio.get_event_loop_policy().get_event_loop()
         if executor is not None:
             raise NotImplementedError("executor argument no longer supported")
         self.parent_loop = loop or asyncio.get_event_loop_policy().get_event_loop()
         self.thread_loop = (
             thread_loop or asyncio.get_event_loop_policy().new_event_loop()
         )
-        self._thread_started = Event()
+        self._thread_started = Event(loop=self.parent_loop)
         if Worker is not None:
             self.Worker = Worker
         super().__init__(loop=self.thread_loop, **kwargs)
+        assert self._shutdown.loop is self.parent_loop
 
     async def on_thread_started(self) -> None:
         ...
@@ -148,7 +150,7 @@ class ServiceThread(Service):
     #      thread calls _shutdown.set(), parent calls _shutdown.wait()
 
     def _new_shutdown_event(self) -> Event:
-        return Event()
+        return Event(loop=self.parent_loop)
 
     async def maybe_start(self) -> bool:
         if not self._thread_started.is_set():
@@ -183,9 +185,8 @@ class ServiceThread(Service):
             if self.last_wakeup_at:
                 if monotonic() - self.last_wakeup_at > 3.0:
                     self.log.error("Thread keepalive is not responding...")
-            asyncio.run_coroutine_threadsafe(
-                self._wakeup_timer_in_thread(), self.thread_loop
-            )
+            await asyncio.sleep(0.0)  # for unittest to invoke `call_soon`
+            await self._wakeup_timer_in_thread()
 
     async def _wakeup_timer_in_thread(self) -> None:
         self.last_wakeup_at = monotonic()
@@ -323,7 +324,7 @@ class MethodQueue(Service):
     def __init__(self, num_workers: int = 2, **kwargs: Any) -> None:
         super().__init__(**kwargs)
         self._queue = asyncio.Queue()
-        self._queue_ready = Event()
+        self._queue_ready = Event(loop=self.loop)
         self.num_workers = num_workers
         self._workers = []
 
